@@ -1,6 +1,9 @@
 use super::*;
 use alloc::format;
-use core::fmt::{Display, Formatter, Result};
+use core::fmt::{Display, Error, Formatter};
+
+/// Type of the parser result.
+pub type PResult<T> = Result<T, PError>;
 
 /// The error of parser handling, returned by [`Parser`].
 ///
@@ -31,7 +34,7 @@ impl PError {
 }
 
 impl Display for PError {
-    fn fmt(&self, f: &mut Formatter) -> Result {
+    fn fmt(&self, f: &mut Formatter) -> Result<(), Error> {
         f.write_fmt(format_args!("{:?}", self))
     }
 }
